@@ -719,14 +719,22 @@ ginv <- function(X, tol = sqrt(.Machine$double.eps)) {
 #' @return the matrix exponential of x.
 #' @export
 matexp <- function(x) {
-  d  <- dim(x)
-  n  <- d[1]
-  p  <- d[2]
-  Ar <- Re(x)
-  Ai <- Im(x)
-  E  <- rbind(cbind(Ar, -Ai), cbind(Ai, Ar))
-  eE <- expm::expm(E)
-  eA <- eE[1:n, 1:n] + (0 + 1i) * eE[(1:n) + n, 1:n]
+  if (utils::compareVersion(as.character(getRversion()), "4.4.0") >= 0) {
+    d  <- dim(x)
+    n  <- d[1]
+    eA <- expm::expm(x) # complex matrices supported since expm v1.0
+  } else {
+    # older R versions don't support complex norm so have to use this slower 
+    # method
+    d  <- dim(x)
+    n  <- d[1]
+    p  <- d[2]
+    Ar <- Re(x)
+    Ai <- Im(x)
+    E  <- rbind(cbind(Ar, -Ai), cbind(Ai, Ar))
+    eE <- expm::expm(E)
+    eA <- eE[1:n, 1:n] + (0 + 1i) * eE[(1:n) + n, 1:n]
+  }
   eA <- matrix(Imzap(eA), ncol = n)
   return(eA)
 }
